@@ -2,7 +2,7 @@ use v5.32;
 
 package Mojolicious::Plugin::DirectoryServer;
 
-our $VERSION = '1.002';
+our $VERSION = '1.004';
 
 use Cwd ();
 use Encode ();
@@ -17,27 +17,33 @@ my $dir_page = <<'PAGE';
   <title>Index of <%= $cur_path %></title>
   <meta http-equiv="content-type" content="text/html; charset=utf-8" />
   <style type='text/css'>
-table { width:100%%; }
-.name { text-align:left; }
-.size, .mtime { text-align:right; }
-.type { width:11em; }
-.mtime { width:15em; }
+table { margin: 0; border-collapse: collapse }
+.name { text-align:left; padding-left: 1em; }
+.size, .mtime { text-align:right; padding-left: 1em; }
+.type  { text-align:left; padding-left: 1em;}
+.mtime { text-align:left; padding-left: 1em; }
   </style>
+<link rel="stylesheet" href="/index.css">
 </head><body>
 <h1>Index of <%= $cur_path %></h1>
-<hr />
-<table>
-  <tr>
-    <th class='name'>Name</th>
-    <th class='size'>Size</th>
-    <th class='type'>Type</th>
-    <th class='mtime'>Last Modified</th>
+<hr id="top-rule"/>
+<table id="listing">
+  <tr id="listing-header" class="<%= $cur_path %>">
+    <th class="name">Name</th>
+    <th class="size">Size</th>
+    <th class="type">Type</th>
+    <th class="mtime">Last Modified</th>
+  </tr>
+  % for my $file (@$files) { my $css_type = $file->{type} =~ s/;.*//r; $css_type =~ s|/|-|g;
+  <tr class="listing-row <%= $css_type %>-type" id="<%= $file->{name} =~ s|/\z||r %>">
+  	<td class="name"><a href='<%= $file->{url} %>'><%== $file->{name} %></a></td>
+  	<td class="size"><%= $file->{size} %></td>
+  	<td class="type"><%= $file->{type} %></td>
+  	<td class="mtime"><%= $file->{mtime} %></td>
   </tr>
-  % for my $file (@$files) {
-  <tr><td class='name'><a href='<%= $file->{url} %>'><%== $file->{name} %></a></td><td class='size'><%= $file->{size} %></td><td class='type'><%= $file->{type} %></td><td class='mtime'><%= $file->{mtime} %></td></tr>
   % }
 </table>
-<hr />
+<hr id="bottom-rule"/>
 </body></html>
 PAGE
 
@@ -180,13 +186,13 @@ Mojolicious::Plugin::DirectoryServer - Serve static files from document root wit
 
   # simple usage
   use Mojolicious::Lite;
-  plugin( 'Directory', root => "/path/to/htdocs" )->start;
+  plugin( 'DirectoryServer', root => "/path/to/htdocs" )->start;
 
   # with handler
   use Text::Markdown qw{ markdown };
   use Path::Class;
   use Encode qw{ decode_utf8 };
-  plugin('Directory', root => "/path/to/htdocs", handler => sub {
+  plugin('DirectoryServer', root => "/path/to/htdocs", handler => sub {
       my ($c, $path) = @_;
       if ( -f $path && $path =~ /\.(md|mkdn)$/ ) {
           my $text = file($path)->slurp;
@@ -197,7 +203,7 @@ Mojolicious::Plugin::DirectoryServer - Serve static files from document root wit
 
 or
 
-  > perl -Mojo -E 'a->plugin("Directory", root => "/path/to/htdocs")->start' daemon
+  > perl -Mojo -E 'a->plugin("DirectoryServer", root => "/path/to/htdocs")->start' daemon
 
 or
 
@@ -205,23 +211,23 @@ or
 
 =head1 DESCRIPTION
 
-L<Mojolicious::Plugin::Directory> is a static file server with a
+L<Mojolicious::Plugin::DirectoryServer> is a static file server with a
 directory index similar to Apache's mod_autoindex.
 
 =head2 Methods
 
-L<Mojolicious::Plugin::Directory> inherits all methods from L<Mojolicious::Plugin>.
+L<Mojolicious::Plugin::DirectoryServer> inherits all methods from L<Mojolicious::Plugin>.
 
 =head2 Options
 
-L<Mojolicious::Plugin::Directory> supports the following options.
+L<Mojolicious::Plugin::DirectoryServer> supports the following options.
 
 =over 4
 
 =item * C<root>
 
   # Mojolicious::Lite
-  plugin Directory => { root => "/path/to/htdocs" };
+  plugin DirectoryServer => { root => "/path/to/htdocs" };
 
 Document root directory. Defaults to the current directory.
 
@@ -230,21 +236,21 @@ If root is a file, serve only root file.
 =item * C<auto_index>
 
    # Mojolicious::Lite
-   plugin Directory => { auto_index => 0 };
+   plugin DirectoryServer => { auto_index => 0 };
 
 Automatically generate index page for directory, default true.
 
 =item * C<dir_index>
 
   # Mojolicious::Lite
-  plugin Directory => { dir_index => [qw/index.html index.htm/] };
+  plugin DirectoryServer => { dir_index => [qw/index.html index.htm/] };
 
 Like a Apache's DirectoryIndex directive.
 
 =item * C<dir_page>
 
   # Mojolicious::Lite
-  plugin Directory => { dir_page => $template_str };
+  plugin DirectoryServer => { dir_page => $template_str };
 
 a HTML template of index page
 
@@ -254,7 +260,7 @@ a HTML template of index page
   use Text::Markdown qw{ markdown };
   use Path::Class;
   use Encode qw{ decode_utf8 };
-  plugin Directory => {
+  plugin DirectoryServer => {
       handler => sub {
           my ($c, $path) = @_;
           if ($path =~ /\.(md|mkdn)$/) {
@@ -274,7 +280,7 @@ If not rendered in CODEREF, serve as static file.
   # Mojolicious::Lite
   # /dir (Accept: application/json)
   # /dir?_format=json
-  plugin Directory => { json => 1 };
+  plugin DirectoryServer => { json => 1 };
 
 Enable json response.
 
